@@ -187,8 +187,8 @@ duplicate_level <- function(emuDBhandle,
                                                 " items.db_uuid, ",
                                                 " items.session, ",
                                                 " items.bundle, ",
-                                                " (item_id + bndl_max_item_id) AS item_id, ' ", 
-                                                duplicateLevelName, "' AS level, ",
+                                                " (item_id + bndl_max_item_id) AS item_id, ", 
+                                                "'", duplicateLevelName, "' AS level, ",
                                                 " type, ",
                                                 " seq_idx, ",
                                                 " sample_rate, ",
